@@ -8,10 +8,12 @@ from forge_sdk.protos import protos
 logger = logging.getLogger('rpc-poke')
 
 
-def build_poke_itx():
+def build_poke_itx(encoded=True):
     poke_tx = protos.PokeTx(date=str(datetime.utcnow().date()),
                             address='zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz')
-    return utils.encode_to_any(type_url='fg:t:poke', data=poke_tx)
+    res = poke_tx if not encoded else utils.encode_to_any(
+        type_url='fg:t:poke', data=poke_tx)
+    return res
 
 
 def build_poke_tx(chain_id, wallet=None, pk=None, address=None):
